specktre
========

specktre is a tool for generating low-contrast desktop wallpapers from
tiling patterns.

Here are some examples of the patterns it produces:

.. image:: output/demo.png

It can be used as a Python library, or invoked from the command-line.
You can also `try it in your browser
<https://alexwlchan.net/experiments/specktre/>`_!

Installation
************

To install specktre, just run:

.. code-block:: console

   $ pip install specktre

Usage
*****

To see a usage message, just run:

.. code-block:: console

   $ specktre --help

There are some examples of specktre used as a script and as a library in
the ``examples`` directory.

License
*******

``specktre`` is licensed under the MIT License.  For more details, see the
``LICENSE`` file in the repository.
